SailsMessageHeader

Struct SailsMessageHeader 

pub struct SailsMessageHeader { /* private fields */ }
Sails message header.

The header is a feature of an IDLv2. It gives opportunity for on top of blockchain services to trace sails messages and programs.

Implementations

Source

impl SailsMessageHeader

pub const fn new( version: Version, hlen: HeaderLength, interface_id: InterfaceId, route_id: u8, entry_id: u16, ) -> Self

Creates a new Sails message header.

pub const fn v1(interface_id: InterfaceId, entry_id: u16, route_id: u8) -> Self

pub const fn version(&self) -> Version

Gets the version of the header.

pub const fn hlen(&self) -> HeaderLength

Gets the header length.

pub const fn interface_id(&self) -> InterfaceId

Gets the interface ID.

pub const fn route_id(&self) -> u8

Gets the route ID.

pub const fn entry_id(&self) -> u16

Gets the entry ID.

Source

impl SailsMessageHeader

pub fn to_bytes(&self) -> Vec<u8>

Serialize header to bytes.

pub fn try_read_bytes(bytes: &mut &[u8]) -> Result<Self, &'static str>

Deserialize header from bytes advancing the slice.

pub fn try_from_bytes(bytes: &[u8]) -> Result<Self, &'static str>

Deserialize header from bytes (expects magic bytes at the start) without mutating the input.

pub fn try_match_interfaces( self, interfaces: &[(InterfaceId, u8)], ) -> Result<MatchedInterface, &'static str>

Tries to match the header’s interface ID and route ID against a list of known interfaces in the program.

If the header has route_id == 0 and exactly one interface ID match exists, the returned MatchedInterface uses the program’s route_id for that interface.