pub struct SailsMessageHeader { /* private fields */ }Expand description
Sails message header.
The header is a feature of an IDLv2. It gives opportunity for on top of blockchain services to trace sails messages and programs.
Implementations
Sourceimpl SailsMessageHeader
impl SailsMessageHeader
Sourcepub const fn new(
version: Version,
hlen: HeaderLength,
interface_id: InterfaceId,
route_id: u8,
entry_id: u16,
) -> Self
pub const fn new( version: Version, hlen: HeaderLength, interface_id: InterfaceId, route_id: u8, entry_id: u16, ) -> Self
Creates a new Sails message header.
pub const fn v1(interface_id: InterfaceId, entry_id: u16, route_id: u8) -> Self
Sourcepub const fn hlen(&self) -> HeaderLength
pub const fn hlen(&self) -> HeaderLength
Gets the header length.
Sourcepub const fn interface_id(&self) -> InterfaceId
pub const fn interface_id(&self) -> InterfaceId
Gets the interface ID.
Sourceimpl SailsMessageHeader
impl SailsMessageHeader
Sourcepub fn try_read_bytes(bytes: &mut &[u8]) -> Result<Self, &'static str>
pub fn try_read_bytes(bytes: &mut &[u8]) -> Result<Self, &'static str>
Deserialize header from bytes advancing the slice.
Sourcepub fn try_from_bytes(bytes: &[u8]) -> Result<Self, &'static str>
pub fn try_from_bytes(bytes: &[u8]) -> Result<Self, &'static str>
Deserialize header from bytes (expects magic bytes at the start) without mutating the input.
Sourcepub fn try_match_interfaces(
self,
interfaces: &[(InterfaceId, u8)],
) -> Result<MatchedInterface, &'static str>
pub fn try_match_interfaces( self, interfaces: &[(InterfaceId, u8)], ) -> Result<MatchedInterface, &'static str>
Tries to match the header’s interface ID and route ID against a list of known interfaces in the program.
If the header has route_id == 0 and exactly one interface ID match exists, the returned MatchedInterface uses the program’s route_id for that interface.